@@ -65,15 +65,12 @@ def importFile():
 
 
 def exportProduct():
-    BwApi.WndMessageBox("h 1", BwApi.BW_API_MB_OK)
     garmentId = BwApi.GarmentId()
 
     current_colorway = BwApi.ColorwayCurrentGet(garmentId)
     new_colorway_id = BwApi.ColorwayClone(garmentId, current_colorway)
 
-    BwApi.WndMessageBox("h 2", BwApi.BW_API_MB_OK)
     BwApi.GarmentDress(garmentId)
-    BwApi.WndMessageBox("h 3", BwApi.BW_API_MB_OK)
     #time.sleep(5)
 
 
@@ -81,7 +78,7 @@ def exportFinish():
     task_params = loadJson('nowyou_task_params.json')
     avatar_params = loadJson('export_schema.json')
 
-    output_name = 'avatar.fbx'
+    output_name = 'product.fbx'
     avatar_params['path'] = os.path.join(task_params['work_path'], output_name)
 
     garmentId = BwApi.GarmentId()
@@ -99,7 +96,7 @@ def BwApiPluginInit():
     BwApi.EventRegister(callback, 0, 0)
     BwApi.EventRegister(callback, 6, 6)
 
-    BwApi.FileMethodRegister(fileCallback, 1, '.mdl', 'ext', 1)
+    BwApi.FileMethodRegister(fileCallback, 1, 'Now you automator', 'mdl', 1)
 
     return int(0x000e0010)
 
